@@ -1,6 +1,7 @@
 package Dancer::Request::Upload;
 
 use File::Spec;
+use Carp;
 
 use strict;
 use warnings;
@@ -16,7 +17,7 @@ sub file_handle {
     my ($self) = @_;
     return $self->{_fh} if defined $self->{_fh};
     open my $fh, '<', $self->tempname
-      or die "Can't open `" . $self->tempname . "' for reading: $!";
+      or croak "Can't open `" . $self->tempname . "' for reading: $!";
     $self->{_fh} = $fh;
 }
 
